==> WinBinder-0.38.133.tgz: Code/Samples/manytests_values.inc.php <==
<?php

//----------------------------------------------------------------- DEPENDENCIES

include_once("../inc/winbinder.php");

//-------------------------------------------------------------------- CONSTANTS

// This RTF was written manually

define("RTF_FMT", "{\\rtf1\\ansi\\ansicpg1252\\deff0\\deflang1033{\\fonttbl{\\f0\\fswiss\\fcharset0 Arial;}{\\f1\\fscript\\fprq2\\fcharset0 Times New Roman;}}{\\colortbl ;\\red128\\green0\\blue0;}\\viewkind4\\uc1\\pard\\cf1\\b\\f0\\fs20 Hello\\cf0\\b0 ,\\pard\\fi568  %s. \\i0\\f1\\par This text is fixed\\f0 .\\par}");

// This RTF is the WordPad output, byte by byte

define("RTF_FILE", "{\\rtf1\\ansi\\ansicpg1252\\deff0\\deflang1033{\\fonttbl{\\f0\\fswiss\\fcharset0 Arial;}{\\f1\\froman\\fprq2\\fcharset0 Times New Roman;}}
{\\colortbl ;\\red128\\green0\\blue0;\\red0\\green0\\blue255;}
\\viewkind4\\uc1\\pard\\cf1\\b\\f0\\fs20 Hello\\cf0\\b0 ,\\par
\\pard\\fi568 This is a \\i \"test\" \\i0\\f1 (Rich Text)\\f0 .\\par
\\pard\\par
\\cf2\\fs16 This text was generated on WordPad.\\cf0\\fs20\\par
}\r\n\0");

//-------------------------------------------------------------------- FUNCTIONS

function test_values($window)
{
//	wb_set_value(wb_get_control($window, IDC_SLIDER4011),		20, 0, 200);
//	wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007),	null, 0, 400);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4026),		50, 0, 10000);
	wb_set_value(wb_get_control($window, IDC_UPDOWN4028),		10, 0, 50);
	wb_set_value(wb_get_control($window, IDC_CHECKBOX4034), 	TRUE);
	wb_set_value(wb_get_control($window, IDC_RADIOBUTTON4015),	TRUE);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4056),	0, 0, 400);

	// List boxes / combo boxes

	wb_set_text(wb_get_control($window, IDC_LISTBOX4053),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_COMBOBOX4054),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_LISTBOX4055),
		"Option1\nOption2\nOption3");

	// Rich text

	wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, "This is a string from inside the source code"));
	file_put_contents("sample.rtf", RTF_FILE);
	wb_set_text(wb_get_control($window, IDC_RICHEDIT4062), file_get_contents("sample.rtf"));
	unlink("sample.rtf");

	// Edit_boxes

	$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
	wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
}

// Window handler

function process_test_values($window, $id, $ctrl=0, $lparam1=0, $lparam2=0)
{
	global $statusbar;

	if($lparam1 == WBC_GETFOCUS) {
		wb_set_text($statusbar, "Focus to control $id");
		return false;
	}

	switch($id) {

		case IDC_EDIT4057:
			if($lparam1 == WBC_KEYPRESS) {
				wb_set_text(wb_get_control($window, IDC_STATIC4048), $lparam2 . "\n" . chr($lparam2));
				break;
			}
			$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
			wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
			wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
			wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, $text));
			wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
			break;

		case IDC_LISTBOX4053:
			if($lparam1 & WBC_DBLCLICK)
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Double-click");
			else
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Single click");
			break;

		case IDC_HSCROLL4056:
		case IDC_SLIDER4011:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007), $value);
			wb_set_text(wb_get_control($window, IDC_STATIC4019), $value);
			wb_set_value(wb_get_control($window, IDC_HSCROLL4026), $value);
			wb_set_value(wb_get_control($window, IDC_VSCROLL4051), $value);
			wb_set_value(wb_get_control($window, IDC_UPDOWN4028), $value);
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048), "Control #$id: value [$value]\n");
			wb_set_value(wb_get_control($window, IDC_EDIT4052), $value);
			break;

		case IDC_RADIOBUTTON4014:
		case IDC_RADIOBUTTON4015:
		case IDC_RADIOBUTTON4016:
			$value = $id - IDC_RADIOBUTTON4014;
			wb_set_value(wb_get_control($window, IDC_LISTBOX4053), $value);
			wb_set_value(wb_get_control($window, IDC_COMBOBOX4054), $value);
			wb_set_value(wb_get_control($window, IDC_LISTBOX4055), $value);
			break;

		case IDC_CHECKBOX4034:
			wb_set_value(wb_get_control($window, IDC_CHECKBOX4049),
				wb_get_value(wb_get_control($window, $id)));
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;

		case IDC_UPDOWN4028:
		case IDC_CHECKBOX4049:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;
	}
}

//-------------------------------------------------------------------------- END

?>

==> WinBinder-0.40.152.tgz: Code/Samples/manytests_values.inc.php <==
<?php

//----------------------------------------------------------------- DEPENDENCIES

include_once("../inc/winbinder.php");

//-------------------------------------------------------------------- CONSTANTS

//-------------------------------------------------------------------- FUNCTIONS

function test_values($window)
{
	wb_set_value(wb_get_control($window, IDC_HSCROLL4026),		50, 0, 10000);
	wb_set_value(wb_get_control($window, IDC_UPDOWN4028),		10, 0, 50);
	wb_set_value(wb_get_control($window, IDC_CHECKBOX4034), 	TRUE);
	wb_set_value(wb_get_control($window, IDC_RADIOBUTTON4015),	TRUE);

	wb_set_range(wb_get_control($window, IDC_HSCROLL4056),		0, 400);
	wb_set_range(wb_get_control($window, IDC_SLIDER4011),		0, 200);
	wb_set_range(wb_get_control($window, IDC_PROGRESSBAR4007),	0, 60);

	// List boxes / combo boxes

	wb_set_text(wb_get_control($window, IDC_LISTBOX4053),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_COMBOBOX4054),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_LISTBOX4055),
		"Option1\nOption2\nOption3");

	// Edit_boxes

	$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
	wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
}

// Window handler

function process_test_values($window, $id, $ctrl=0, $lparam1=0, $lparam2=0)
{
	global $statusbar;

	if($lparam1 == WBC_GETFOCUS) {
		wb_set_text($statusbar, "Focus to control $id");
		return false;
	}

	switch($id) {

		case IDC_EDIT4069:
		case IDC_EDIT4071:
			if($lparam1 == WBC_KEYDOWN)
				wb_set_text($statusbar, "Char $lparam2: " . chr($lparam2));
			break;

		case IDC_EDIT4057:
			if($lparam1 == WBC_KEYDOWN) {
				wb_set_text($statusbar, "Char $lparam2: " . chr($lparam2));
//				wb_set_text(wb_get_control($window, IDC_STATIC4048), $lparam2 . "\n" . chr($lparam2));
				break;
			}
			$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
			wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
			wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
			wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
			break;

		case IDC_LISTBOX4053:
			if($lparam1 & WBC_DBLCLICK)
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Double-click");
			else
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Single click");
			break;

		case IDC_HSCROLL4056:
		case IDC_SLIDER4011:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007), $value);
			wb_set_text(wb_get_control($window, IDC_STATIC4019), $value);
			wb_set_value(wb_get_control($window, IDC_HSCROLL4026), $value);
			wb_set_value(wb_get_control($window, IDC_VSCROLL4051), $value);
			wb_set_value(wb_get_control($window, IDC_UPDOWN4028), $value);
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048), "Control #$id: value [$value]\n");
			wb_set_value(wb_get_control($window, IDC_EDIT4052), $value);
			break;

		case IDC_RADIOBUTTON4014:
		case IDC_RADIOBUTTON4015:
		case IDC_RADIOBUTTON4016:
			$value = $id - IDC_RADIOBUTTON4014;
			wb_set_value(wb_get_control($window, IDC_LISTBOX4053), $value);
			wb_set_value(wb_get_control($window, IDC_COMBOBOX4054), $value);
			wb_set_value(wb_get_control($window, IDC_LISTBOX4055), $value);
			break;

		case IDC_CHECKBOX4034:
			wb_set_selected(wb_get_control($window, IDC_CHECKBOX4049),
				wb_get_selected($ctrl));
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;

		case IDC_UPDOWN4028:
		case IDC_CHECKBOX4049:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;
	}
}

//-------------------------------------------------------------------------- END

?>
